nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Misc0Set

Struct Misc0Set 

#[repr(transparent)]
pub struct Misc0Set(pub u32);
Miscellaneous Register 0

Tuple Fields

0: u32

Implementations

Source

impl Misc0Set

pub const fn reftop_pwd(&self) -> bool

Control bit to power-down the analog bandgap reference circuitry

pub const fn set_reftop_pwd(&mut self, val: bool)

Control bit to power-down the analog bandgap reference circuitry

pub const fn reftop_pwdvbgup(&self) -> bool

Control bit to power down the VBG-up detection circuitry in the analog bandgap.

pub const fn set_reftop_pwdvbgup(&mut self, val: bool)

Control bit to power down the VBG-up detection circuitry in the analog bandgap.

pub const fn reftop_lowpower(&self) -> bool

Control bit to enable the low-power mode in the analog bandgap.

pub const fn set_reftop_lowpower(&mut self, val: bool)

Control bit to enable the low-power mode in the analog bandgap.

pub const fn reftop_selfbiasoff(&self) -> Misc0SetReftopSelfbiasoff

Control bit to disable the self-bias circuit in the analog bandgap

pub const fn set_reftop_selfbiasoff(&mut self, val: Misc0SetReftopSelfbiasoff)

Control bit to disable the self-bias circuit in the analog bandgap

pub const fn reftop_vbgadj(&self) -> Misc0SetReftopVbgadj

no description available

pub const fn set_reftop_vbgadj(&mut self, val: Misc0SetReftopVbgadj)

no description available

pub const fn reftop_vbgup(&self) -> bool

Status bit that signals the analog bandgap voltage is up and stable. 1 - Stable.

pub const fn set_reftop_vbgup(&mut self, val: bool)

Status bit that signals the analog bandgap voltage is up and stable. 1 - Stable.

pub const fn stop_mode_config(&self) -> Misc0SetStopModeConfig

Configure the analog behavior in stop mode.

pub const fn set_stop_mode_config(&mut self, val: Misc0SetStopModeConfig)

Configure the analog behavior in stop mode.

pub const fn discon_high_snvs(&self) -> Misc0SetDisconHighSnvs

This bit controls a switch from VDD_HIGH_IN to VDD_SNVS_IN.

pub const fn set_discon_high_snvs(&mut self, val: Misc0SetDisconHighSnvs)

This bit controls a switch from VDD_HIGH_IN to VDD_SNVS_IN.

pub const fn osc_i(&self) -> Misc0SetOscI

This field determines the bias current in the 24MHz oscillator

pub const fn set_osc_i(&mut self, val: Misc0SetOscI)

This field determines the bias current in the 24MHz oscillator

pub const fn osc_xtalok(&self) -> bool

Status bit that signals that the output of the 24-MHz crystal oscillator is stable

pub const fn set_osc_xtalok(&mut self, val: bool)

Status bit that signals that the output of the 24-MHz crystal oscillator is stable

pub const fn osc_xtalok_en(&self) -> bool

This bit enables the detector that signals when the 24MHz crystal oscillator is stable

pub const fn set_osc_xtalok_en(&mut self, val: bool)

This bit enables the detector that signals when the 24MHz crystal oscillator is stable

pub const fn clkgate_ctrl(&self) -> Misc0SetClkgateCtrl

This bit allows disabling the clock gate (always ungated) for the xtal 24MHz clock that clocks the digital logic in the analog block

pub const fn set_clkgate_ctrl(&mut self, val: Misc0SetClkgateCtrl)

This bit allows disabling the clock gate (always ungated) for the xtal 24MHz clock that clocks the digital logic in the analog block

pub const fn clkgate_delay(&self) -> Misc0SetClkgateDelay

This field specifies the delay between powering up the XTAL 24MHz clock and releasing the clock to the digital logic inside the analog block

pub const fn set_clkgate_delay(&mut self, val: Misc0SetClkgateDelay)

This field specifies the delay between powering up the XTAL 24MHz clock and releasing the clock to the digital logic inside the analog block

pub const fn rtc_xtal_source(&self) -> Misc0SetRtcXtalSource

This field indicates which chip source is being used for the rtc clock.

pub const fn set_rtc_xtal_source(&mut self, val: Misc0SetRtcXtalSource)

This field indicates which chip source is being used for the rtc clock.

pub const fn xtal_24m_pwd(&self) -> bool

This field powers down the 24M crystal oscillator if set true.

pub const fn set_xtal_24m_pwd(&mut self, val: bool)

This field powers down the 24M crystal oscillator if set true.

pub const fn vid_pll_prediv(&self) -> Misc0SetVidPllPrediv

Predivider for the source clock of the PLL’s.

pub const fn set_vid_pll_prediv(&mut self, val: Misc0SetVidPllPrediv)

Predivider for the source clock of the PLL’s.