#[repr(transparent)]pub struct Misc2Set(pub u32);Expand description
Miscellaneous Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Misc2Set
impl Misc2Set
Sourcepub const fn reg0_bo_offset(&self) -> Misc2SetReg0BoOffset
pub const fn reg0_bo_offset(&self) -> Misc2SetReg0BoOffset
This field defines the brown out voltage offset for the CORE power domain
Sourcepub const fn set_reg0_bo_offset(&mut self, val: Misc2SetReg0BoOffset)
pub const fn set_reg0_bo_offset(&mut self, val: Misc2SetReg0BoOffset)
This field defines the brown out voltage offset for the CORE power domain
Sourcepub const fn reg0_bo_status(&self) -> bool
pub const fn reg0_bo_status(&self) -> bool
Reg0 brownout status bit.
Sourcepub const fn set_reg0_bo_status(&mut self, val: bool)
pub const fn set_reg0_bo_status(&mut self, val: bool)
Reg0 brownout status bit.
Sourcepub const fn reg0_enable_bo(&self) -> bool
pub const fn reg0_enable_bo(&self) -> bool
Enables the brownout detection.
Sourcepub const fn set_reg0_enable_bo(&mut self, val: bool)
pub const fn set_reg0_enable_bo(&mut self, val: bool)
Enables the brownout detection.
Sourcepub const fn pll3_disable(&self) -> bool
pub const fn pll3_disable(&self) -> bool
Default value of “0”
Sourcepub const fn set_pll3_disable(&mut self, val: bool)
pub const fn set_pll3_disable(&mut self, val: bool)
Default value of “0”
Sourcepub const fn reg1_bo_offset(&self) -> Misc2SetReg1BoOffset
pub const fn reg1_bo_offset(&self) -> Misc2SetReg1BoOffset
This field defines the brown out voltage offset for the xPU power domain
Sourcepub const fn set_reg1_bo_offset(&mut self, val: Misc2SetReg1BoOffset)
pub const fn set_reg1_bo_offset(&mut self, val: Misc2SetReg1BoOffset)
This field defines the brown out voltage offset for the xPU power domain
Sourcepub const fn reg1_bo_status(&self) -> bool
pub const fn reg1_bo_status(&self) -> bool
Reg1 brownout status bit.
Sourcepub const fn set_reg1_bo_status(&mut self, val: bool)
pub const fn set_reg1_bo_status(&mut self, val: bool)
Reg1 brownout status bit.
Sourcepub const fn reg1_enable_bo(&self) -> bool
pub const fn reg1_enable_bo(&self) -> bool
Enables the brownout detection.
Sourcepub const fn set_reg1_enable_bo(&mut self, val: bool)
pub const fn set_reg1_enable_bo(&mut self, val: bool)
Enables the brownout detection.
Sourcepub const fn audio_div_lsb(&self) -> Misc2SetAudioDivLsb
pub const fn audio_div_lsb(&self) -> Misc2SetAudioDivLsb
LSB of Post-divider for Audio PLL
Sourcepub const fn set_audio_div_lsb(&mut self, val: Misc2SetAudioDivLsb)
pub const fn set_audio_div_lsb(&mut self, val: Misc2SetAudioDivLsb)
LSB of Post-divider for Audio PLL
Sourcepub const fn reg2_bo_offset(&self) -> Misc2SetReg2BoOffset
pub const fn reg2_bo_offset(&self) -> Misc2SetReg2BoOffset
This field defines the brown out voltage offset for the xPU power domain
Sourcepub const fn set_reg2_bo_offset(&mut self, val: Misc2SetReg2BoOffset)
pub const fn set_reg2_bo_offset(&mut self, val: Misc2SetReg2BoOffset)
This field defines the brown out voltage offset for the xPU power domain
Sourcepub const fn reg2_bo_status(&self) -> bool
pub const fn reg2_bo_status(&self) -> bool
Reg2 brownout status bit.
Sourcepub const fn set_reg2_bo_status(&mut self, val: bool)
pub const fn set_reg2_bo_status(&mut self, val: bool)
Reg2 brownout status bit.
Sourcepub const fn reg2_enable_bo(&self) -> bool
pub const fn reg2_enable_bo(&self) -> bool
Enables the brownout detection.
Sourcepub const fn set_reg2_enable_bo(&mut self, val: bool)
pub const fn set_reg2_enable_bo(&mut self, val: bool)
Enables the brownout detection.
Sourcepub const fn reg2_ok(&self) -> bool
pub const fn reg2_ok(&self) -> bool
Signals that the voltage is above the brownout level for the SOC supply
Sourcepub const fn set_reg2_ok(&mut self, val: bool)
pub const fn set_reg2_ok(&mut self, val: bool)
Signals that the voltage is above the brownout level for the SOC supply
Sourcepub const fn audio_div_msb(&self) -> Misc2SetAudioDivMsb
pub const fn audio_div_msb(&self) -> Misc2SetAudioDivMsb
MSB of Post-divider for Audio PLL
Sourcepub const fn set_audio_div_msb(&mut self, val: Misc2SetAudioDivMsb)
pub const fn set_audio_div_msb(&mut self, val: Misc2SetAudioDivMsb)
MSB of Post-divider for Audio PLL
Sourcepub const fn reg0_step_time(&self) -> Misc2SetReg0StepTime
pub const fn reg0_step_time(&self) -> Misc2SetReg0StepTime
Number of clock periods (24MHz clock).
Sourcepub const fn set_reg0_step_time(&mut self, val: Misc2SetReg0StepTime)
pub const fn set_reg0_step_time(&mut self, val: Misc2SetReg0StepTime)
Number of clock periods (24MHz clock).
Sourcepub const fn reg1_step_time(&self) -> Misc2SetReg1StepTime
pub const fn reg1_step_time(&self) -> Misc2SetReg1StepTime
Number of clock periods (24MHz clock).
Sourcepub const fn set_reg1_step_time(&mut self, val: Misc2SetReg1StepTime)
pub const fn set_reg1_step_time(&mut self, val: Misc2SetReg1StepTime)
Number of clock periods (24MHz clock).
Sourcepub const fn reg2_step_time(&self) -> Misc2SetReg2StepTime
pub const fn reg2_step_time(&self) -> Misc2SetReg2StepTime
Number of clock periods (24MHz clock).
Sourcepub const fn set_reg2_step_time(&mut self, val: Misc2SetReg2StepTime)
pub const fn set_reg2_step_time(&mut self, val: Misc2SetReg2StepTime)
Number of clock periods (24MHz clock).
Sourcepub const fn video_div(&self) -> Misc2SetVideoDiv
pub const fn video_div(&self) -> Misc2SetVideoDiv
Post-divider for video
Sourcepub const fn set_video_div(&mut self, val: Misc2SetVideoDiv)
pub const fn set_video_div(&mut self, val: Misc2SetVideoDiv)
Post-divider for video