#[repr(transparent)]pub struct RegCore(pub u32);Expand description
Digital Regulator Core Register
Tuple Fields
0: u32Implementations
Sourceimpl RegCore
impl RegCore
Sourcepub const fn reg0_targ(&self) -> RegCoreReg0Targ
pub const fn reg0_targ(&self) -> RegCoreReg0Targ
This field defines the target voltage for the Arm core power domain
Sourcepub const fn set_reg0_targ(&mut self, val: RegCoreReg0Targ)
pub const fn set_reg0_targ(&mut self, val: RegCoreReg0Targ)
This field defines the target voltage for the Arm core power domain
Sourcepub const fn reg0_adj(&self) -> RegCoreReg0Adj
pub const fn reg0_adj(&self) -> RegCoreReg0Adj
This bit field defines the adjustment bits to calibrate the target value of Reg0. The adjustment is applied on top on any adjustment applied to the global reference in the misc0 register.
Sourcepub const fn set_reg0_adj(&mut self, val: RegCoreReg0Adj)
pub const fn set_reg0_adj(&mut self, val: RegCoreReg0Adj)
This bit field defines the adjustment bits to calibrate the target value of Reg0. The adjustment is applied on top on any adjustment applied to the global reference in the misc0 register.
Sourcepub const fn reg1_targ(&self) -> RegCoreReg1Targ
pub const fn reg1_targ(&self) -> RegCoreReg1Targ
This bit field defines the target voltage for the vpu/gpu power domain. Single bit increments reflect 25mV core voltage steps. Not all steps will make sense to use either because of input supply limitations or load operation.
Sourcepub const fn set_reg1_targ(&mut self, val: RegCoreReg1Targ)
pub const fn set_reg1_targ(&mut self, val: RegCoreReg1Targ)
This bit field defines the target voltage for the vpu/gpu power domain. Single bit increments reflect 25mV core voltage steps. Not all steps will make sense to use either because of input supply limitations or load operation.
Sourcepub const fn reg1_adj(&self) -> RegCoreReg1Adj
pub const fn reg1_adj(&self) -> RegCoreReg1Adj
This bit field defines the adjustment bits to calibrate the target value of Reg1. The adjustment is applied on top on any adjustment applied to the global reference in the misc0 register.
Sourcepub const fn set_reg1_adj(&mut self, val: RegCoreReg1Adj)
pub const fn set_reg1_adj(&mut self, val: RegCoreReg1Adj)
This bit field defines the adjustment bits to calibrate the target value of Reg1. The adjustment is applied on top on any adjustment applied to the global reference in the misc0 register.
Sourcepub const fn reg2_targ(&self) -> RegCoreReg2Targ
pub const fn reg2_targ(&self) -> RegCoreReg2Targ
This field defines the target voltage for the SOC power domain
Sourcepub const fn set_reg2_targ(&mut self, val: RegCoreReg2Targ)
pub const fn set_reg2_targ(&mut self, val: RegCoreReg2Targ)
This field defines the target voltage for the SOC power domain
Sourcepub const fn reg2_adj(&self) -> RegCoreReg2Adj
pub const fn reg2_adj(&self) -> RegCoreReg2Adj
This bit field defines the adjustment bits to calibrate the target value of Reg2. The adjustment is applied on top on any adjustment applied to the global reference in the misc0 register.
Sourcepub const fn set_reg2_adj(&mut self, val: RegCoreReg2Adj)
pub const fn set_reg2_adj(&mut self, val: RegCoreReg2Adj)
This bit field defines the adjustment bits to calibrate the target value of Reg2. The adjustment is applied on top on any adjustment applied to the global reference in the misc0 register.
Sourcepub const fn ramp_rate(&self) -> RegCoreRampRate
pub const fn ramp_rate(&self) -> RegCoreRampRate
Regulator voltage ramp rate.
Sourcepub const fn set_ramp_rate(&mut self, val: RegCoreRampRate)
pub const fn set_ramp_rate(&mut self, val: RegCoreRampRate)
Regulator voltage ramp rate.
Sourcepub const fn fet_odrive(&self) -> bool
pub const fn fet_odrive(&self) -> bool
If set, increases the gate drive on power gating FETs to reduce leakage in the off state
Sourcepub const fn set_fet_odrive(&mut self, val: bool)
pub const fn set_fet_odrive(&mut self, val: bool)
If set, increases the gate drive on power gating FETs to reduce leakage in the off state